import { ErrorHandler } from '../error/index.js';
export class AbstractPaymentResponse {
    common(response, modality) {
        const { nit = '', nsu = '', message = '', code = '', } = response;
        return {
            message,
            messageCode: code,
            result: {
                nit,
                nsu,
                gatewayMessage: message,
                gatewayResponse: response,
            },
        };
    }
    credit(response) {
        return response;
    }
    pix(response) {
        const { nit, nsu, gatewayMessage, gatewayResponse } = response.result;
        let qrCode = '';
        if (gatewayResponse.payment && gatewayResponse.payment.qr_code) {
            qrCode = gatewayResponse.payment.qr_code;
        }
        response.result = {
            nit,
            nsu,
            qrCode,
            gatewayMessage,
            gatewayResponse,
        };
        return response;
    }
    billet(response) {
        return response;
    }
    debit(response) {
        return response;
    }
    getModalityFunction(modality) {
        const functionToCall = this[modality] || null;
        if (typeof functionToCall !== 'function') {
            throw ErrorHandler.invalidChoice('modality', modality);
        }
        return functionToCall;
    }
    handle(response, modality) {
        const copyObj = (obj) => JSON.parse(JSON.stringify(obj));
        const commonResponse = this.common(copyObj(response), modality);
        const functionToCall = this.getModalityFunction(modality);
        const responseByModality = functionToCall.apply(this, [commonResponse]);
        return responseByModality;
    }
    handleConfirmation(response) {
        return response;
    }
}
