export class ParameterError extends Error {
    constructor() {
        super(...arguments);
        this.message = '';
        this.code = '';
        this.data = {};
        this.messages = {
            'EMPTY': 'Empty param',
            'INVALID': 'Invalid parameter(s)',
            'INVALID_OPTION': 'Option {{optionName}} is invalid or not implemented to value {{optionValue}}',
            'INVALID_TYPE': 'Invalid type of {{parameter}}. Expected: {{expected}} | Received: {{received}}',
            'INVALID_FORMAT': 'Invalid {{parameter}} format. (E.g {{format}})',
            'NOT_FOUND': 'Parameter(s) not found',
            'NOT_IMPLEMENTED': 'Resource not implemented',
        };
    }
    to(errorType, param) {
        this.code = errorType;
        this.message = this.getMessageByType(errorType, param);
        this.data = param;
        return this;
    }
    replaceMessageParameters(message, parameter) {
        const MNEMONIC_PATTERN = /(?<={{)\w+(?=}})/gi;
        const mnemonics = message.match(MNEMONIC_PATTERN);
        let messageWithParams = message;
        if (Array.isArray(mnemonics) && mnemonics.length) {
            [...new Set(mnemonics)].forEach(mnemonicName => {
                const value = parameter[mnemonicName];
                messageWithParams = messageWithParams.replaceAll(`{{${mnemonicName}}}`, value);
            });
        }
        return messageWithParams;
    }
    getMessageByType(errorType, param) {
        const message = this.replaceMessageParameters(this.messages[errorType], param);
        return message;
    }
    triggerException() {
        throw this;
    }
}
