import { RequestApi, PayloadValidation } from '../helper/index.js';
import { CardRequest, PaymentRequest, PaymentResponse } from '../service/index.js';
class Payment {
    async credit(payload) {
        try {
            PayloadValidation.isValidPayload(payload);
            const creditPayload = PaymentRequest.handle(payload, 'credit');
            const transaction = await RequestApi.createTransaction(creditPayload);
            if (!transaction || !transaction.payment) {
                return PaymentResponse.handle(transaction, 'credit');
            }
            creditPayload.nit = transaction.payment.nit;
            const response = await RequestApi.makePayment(creditPayload);
            return PaymentResponse.handle(response, 'credit');
        }
        catch (error) {
            return Promise.reject(error);
        }
    }
    async pix(payload) {
        PayloadValidation.isValidPayload(payload);
        const pixPayload = PaymentRequest.handle(payload, 'pix');
        const transaction = await RequestApi.createTransaction(pixPayload);
        if (!transaction || !transaction.payment) {
            return PaymentResponse.handle(transaction, 'pix');
        }
        pixPayload.nit = transaction.payment.nit;
        const response = await RequestApi.makePayment(pixPayload);
        return PaymentResponse.handle(response, 'pix');
    }
    async confirm(payload) {
        PayloadValidation.confirm(payload);
        const response = await RequestApi.paymentConfirmation(payload);
        return PaymentResponse.handleConfirmation(response);
    }
    async cancel(payload) {
        PayloadValidation.confirm(payload);
        const response = await RequestApi.paymentCancellation(payload);
        return PaymentResponse.handleCancellation(response);
    }
    async consult(payload) {
        PayloadValidation.confirm(payload);
        const response = await RequestApi.paymentConsult(payload);
        return PaymentResponse.handleConsult(response);
    }
    async storeCard(payload) {
        PayloadValidation.storeCard(payload);
        const response = await RequestApi.storeCard(CardRequest.storeCard(payload));
        return PaymentResponse.handleStoreCard(response);
    }
}
const instance = new Payment();
export { instance as PaymentController };
