import { ErrorHandler } from '../../../error/index.js';
import { AbstractPayloadValidation } from '../../../abstract/index.js';
class PayloadValidation extends AbstractPayloadValidation {
    isValidCredentials(payload) {
        if (!payload.credentials)
            throw ErrorHandler.parameterNotFound('credentials');
        if (!payload.credentials.merchantId || !payload.credentials.merchantKey) {
            throw ErrorHandler.parameterNotFound(['merchantId', 'merchantKey']);
        }
    }
    credit(payload) {
        super.credit(payload);
        if (!payload.authorizer) {
            throw ErrorHandler.parameterNotFound('authorizer');
        }
        if (typeof payload.authorizer !== 'string') {
            throw ErrorHandler.invalidParameterType('authorizer', 'string', typeof payload.authorizer);
        }
        return true;
    }
    isValidPayload(payload) {
        super.isValidPayload(payload);
        this.isValidCredentials(payload);
        return true;
    }
}
const instance = new PayloadValidation();
export { instance as PayloadValidation };
