import { Request } from "../../../helper/index.js";
class RequestApi {
    constructor() {
        this.url = process.env.API_SOFTWARE_EXPRESS_URL;
    }
    getUrlByEndPoint(endPoint) {
        const url = Request.handleUrl({
            baseUrl: this.url || '',
            endPoint,
        });
        return url;
    }
    async send(endPoint, payload, requestType = 'post') {
        try {
            const { credentials, ...payloadToSend } = payload;
            delete payloadToSend.paymentCompany;
            const url = this.getUrlByEndPoint(endPoint);
            const dataToSend = {
                header: [
                    `merchant_id: ${payload.credentials.merchantId}`,
                    `merchant_key: ${payload.credentials.merchantKey}`,
                ],
                data: payloadToSend,
            };
            let response, result = {};
            switch (requestType) {
                case 'post':
                    response = await Request.post(url, dataToSend);
                    result = response.data;
                    break;
                case 'put':
                    response = await Request.put(url, dataToSend);
                    result = response.data;
                    break;
                case 'get':
                    response = await Request.get(url, dataToSend);
                    result = response.data;
                    break;
            }
            return result;
        }
        catch (error) {
            return Promise.reject(error);
        }
    }
    async createTransaction(payload) {
        try {
            const response = await this.send('/transactions', payload);
            return response;
        }
        catch (error) {
            return Promise.reject(error);
        }
    }
    async makePayment(payload) {
        try {
            const response = await this.send(`/payments/${payload.nit}`, payload, 'post');
            return response;
        }
        catch (error) {
            return Promise.reject(error);
        }
    }
    async paymentConfirmation(payload) {
        try {
            const response = await this.send(`/payments/${payload.nit}?confirm=true`, payload, 'put');
            return response;
        }
        catch (error) {
            return Promise.reject(error);
        }
    }
    async paymentCancellation(payload) {
        try {
            const response = await this.send(`/payments/${payload.nit}?confirm=false`, payload, 'put');
            return response;
        }
        catch (error) {
            return Promise.reject(error);
        }
    }
    async paymentConsult(payload) {
        try {
            const response = await this.send(`/transactions/${payload.nit}`, payload, 'get');
            return response;
        }
        catch (error) {
            return Promise.reject(error);
        }
    }
    async storeCard(payload) {
        try {
            const response = await this.send('/cards', payload, 'post');
            return response;
        }
        catch (error) {
            return Promise.reject(error);
        }
    }
    async verifyCard(payload, nit) {
        try {
            const response = await this.send(`/payments/${nit}/cards`, payload, 'post');
            return response;
        }
        catch (error) {
            return Promise.reject(error);
        }
    }
}
const instance = new RequestApi();
export { instance as RequestApi };
