import { AbstractPaymentRequest } from '../../../abstract/index.js';
import { Text } from '../../../helper/index.js';
import { RequestData } from './index.js';
class PaymentRequest extends AbstractPaymentRequest {
    setInstallment(payload) {
        payload.installmentType = '4';
    }
    credit(payload) {
        const parsedPayload = super.credit(payload);
        RequestData.setAuthorizerCode(parsedPayload);
        const { card } = parsedPayload;
        const { expiryDate = '', securityCode = '', holder = '', ...otherInfo } = card;
        parsedPayload.card = { ...otherInfo };
        if (expiryDate) {
            parsedPayload.card.expiry_date = expiryDate;
        }
        if (securityCode) {
            parsedPayload.card.security_code = securityCode;
        }
        if (payload.postponeConfirmation) {
            payload.additional_data = payload.additional_data || {};
            payload.additional_data.postpone_confirmation = true;
        }
        if (holder) {
            parsedPayload.card.holder = Text.sanitize(holder);
        }
        return { ...parsedPayload };
    }
    pix(payload) {
        const parsedPayload = super.pix(payload);
        payload.authorizer = 'PIX';
        RequestData.setAuthorizerCode(parsedPayload);
        return parsedPayload;
    }
    common(payload) {
        this.setInstallment(payload);
        const { installmentType, orderId, merchantUsn, ...payloadToSend } = payload;
        return {
            ...payloadToSend,
            installment_type: installmentType,
            order_id: orderId,
            merchant_usn: merchantUsn || RequestData.generateMerchantUsn(),
        };
    }
}
const instance = new PaymentRequest();
export { instance as PaymentRequest };
