import { AbstractPaymentResponse } from '../../../abstract/index.js';
import { Messages } from '../../../helper/index.js';
class PaymentResponse extends AbstractPaymentResponse {
    getMessageByStatusCode(code) {
        const responseCodeMap = {
            0: 'SUCCESS_PAYMENT',
            102: 'TRANSACTION_IN_PROGRESS_OR_FINALIZED',
            255: 'PAYMENT_DENIED',
        };
        return responseCodeMap[code] || 'FAIL_PAYMENT';
    }
    getPaymentStatusByCode(code) {
        return {
            NOV: 'NEW',
            INV: 'INVALID',
            PPC: 'CONFIRMATION_PENDING',
            PPN: 'UNDONE',
            PEN: 'AWAITING_PAYMENT',
            CON: 'CONFIRMED',
            NEG: 'DENIED',
            ERR: 'ERROR_PAYMENT',
            BLQ: 'BLOCKED',
            EXP: 'EXPIRED',
            EST: 'REFUND',
            AGU: 'AWAITING_USER',
            ABA: 'ABANDONED',
            CAN: 'CANCELLED',
            RET: 'RETRY',
        }[code] || code;
    }
    handleNsu(nsu) {
        const [onlyDigits] = (nsu || '').match(/\d+/g) || [];
        return onlyDigits || '';
    }
    getPaymentInfo(response) {
        const payment = {
            nit: '',
            nsu: '',
        };
        if (response && response.payment) {
            payment.nit = response.payment.nit || '';
            payment.nsu = this.handleNsu(response.payment.host_usn);
        }
        return payment;
    }
    common(response, modality) {
        const messageCode = this.getMessageByStatusCode(response.code);
        const message = Messages.getMessageByCode(messageCode, {
            paymentModality: modality,
        });
        const { nit, nsu } = this.getPaymentInfo(response);
        const structuredResponse = {
            message,
            messageCode,
            result: {
                nsu,
                nit,
                gatewayMessage: response.message,
                gatewayResponse: response,
            },
        };
        return structuredResponse;
    }
    handleConfirmation(response) {
        const messageCode = response.code === '0' ? 'SUCCESS_PAYMENT_CONFIRM' : 'FAIL_PAYMENT_CONFIRM';
        const message = Messages.getMessageByCode(messageCode);
        const { nit, nsu } = this.getPaymentInfo(response);
        return {
            message,
            messageCode,
            result: {
                nit,
                nsu,
                gatewayMessage: response.message,
                gatewayResponse: response,
            }
        };
    }
    handleCancellation(response) {
        const messageCode = response.code === '0' ? 'SUCCESS_PAYMENT_CANCEL' : 'FAIL_PAYMENT_CANCEL';
        const message = Messages.getMessageByCode(messageCode);
        const { nit, nsu } = this.getPaymentInfo(response);
        return {
            message,
            messageCode,
            result: {
                nit,
                nsu,
                gatewayMessage: response.message,
                gatewayResponse: response,
            }
        };
    }
    handleConsult(response) {
        const messageCode = response.code === '0' ? 'SUCCESS_TRANSACTION_CONSULT' : 'FAIL_TRANSACTION_CONSULT';
        const message = Messages.getMessageByCode(messageCode);
        const { nit, nsu } = this.getPaymentInfo(response);
        return {
            message,
            messageCode,
            result: {
                nit,
                nsu,
                status: this.getPaymentStatusByCode(response.payment.status),
                gatewayMessage: response.message,
                gatewayResponse: response,
            }
        };
    }
    handleStoreCard(response) {
        const messageCode = response.code === '0' ? 'SUCCESS_STORED_CARD' : 'FAILURE_TO_STORE_CARD';
        const message = Messages.getMessageByCode(messageCode);
        const { nit, nsu } = this.getPaymentInfo(response);
        return {
            message,
            messageCode,
            result: {
                nit,
                nsu,
                token: response && response.card ? response.card.token : '',
                gatewayMessage: response.message,
                gatewayResponse: response,
            }
        };
    }
}
const instance = new PaymentResponse();
export { instance as PaymentResponse };
