import { curly } from 'node-libcurl';
import { LogData, Logger } from '../log/index.js';
class Request {
    getAllParams(req) {
        return { ...req.body, ...req.params };
    }
    handleUrl({ baseUrl, endPoint }) {
        const removeStartEndBar = (str) => str.replace(/^\/|\/+$/g, '');
        const baseUrlFormatted = removeStartEndBar(baseUrl);
        const endPointFormatted = removeStartEndBar(endPoint);
        return `${baseUrlFormatted}/${endPointFormatted}`;
    }
    handleCurlParams(params, requestType) {
        const header = params.header || [];
        header.push('Content-Type: application/json');
        header.push('Accept: application/json');
        const curlParams = {
            httpHeader: header,
            postFields: '',
            caInfo: process.env.API_CERT_FILE_PATH
        };
        if (requestType === 'get') {
            delete curlParams.postFields;
        }
        else {
            curlParams.postFields = JSON.stringify(params.data);
        }
        return curlParams;
    }
    async send(route, params, requestType) {
        const curlParams = this.handleCurlParams(params, requestType);
        const functionToCall = curly[requestType] || null;
        if (typeof functionToCall !== 'function') {
            throw new Error(`Invalid request type {${requestType}}`);
        }
        Logger.info(LogData.handle({ '[url]': route, '[method]': requestType.toUpperCase(), ...params.data }));
        return functionToCall.apply(curly, [route, curlParams]);
    }
    get(route, params) {
        return this.send(route, params, 'get');
    }
    post(route, params) {
        return this.send(route, params, 'post');
    }
    put(route, params) {
        return this.send(route, params, 'put');
    }
    delete(route, params) {
        return this.send(route, params, 'delete');
    }
}
const instance = new Request();
export { instance as Request };
