/**
 * @doc
 * Unicode list reference
 * > https://www.unicode.org/charts/fr/PDF/U0080.pdf
*/
class Text {
    constructor() {
        this.sanitizePatterns = [
            { pattern: /[\u00C0-\u00C5]/g, toReplace: 'A' },
            { pattern: /[\u00E0-\u00E5]/g, toReplace: 'a' },
            { pattern: /[\u00C8-\u00CB]/g, toReplace: 'E' },
            { pattern: /[\u00E8-\u00EB]/g, toReplace: 'e' },
            { pattern: /[\u00CC-\u00CF]/g, toReplace: 'I' },
            { pattern: /[\u00EC-\u00EF]/g, toReplace: 'i' },
            { pattern: /[\u00D2-\u00D6]/g, toReplace: 'O' },
            { pattern: /[\u00F2-\u00F6]/g, toReplace: 'o' },
            { pattern: /[\u00D9-\u00DC]/g, toReplace: 'U' },
            { pattern: /[\u00F9-\u00FC]/g, toReplace: 'u' },
            { pattern: /\u00C7/g, toReplace: 'C' },
            { pattern: /\u00E7/g, toReplace: 'c' },
            { pattern: /\u00D1/g, toReplace: 'N' },
            { pattern: /\u00F1/g, toReplace: 'n' },
            { pattern: /[^\w]|_/g, toReplace: '' },
        ];
    }
    sanitize(value) {
        const applyPatterns = function (newValue, item) {
            const { pattern, toReplace } = item;
            return newValue.replace(pattern, toReplace);
        };
        return this.sanitizePatterns.reduce(applyPatterns, value);
    }
}
const instance = new Text();
export { instance as Text };
