import * as winston from 'winston';
import DailyRotateFile from 'winston-daily-rotate-file';
const errorTransport = new DailyRotateFile({
    level: 'error',
    filename: 'api-%DATE%-error.log',
    dirname: process.env.API_LOG_PATH || './temp',
    zippedArchive: true,
    datePattern: 'YYYY-MM-DD',
    maxFiles: '90d',
});
const infoTransport = new DailyRotateFile({
    level: 'info',
    filename: 'api-%DATE%-info.log',
    dirname: process.env.API_LOG_PATH || './temp',
    datePattern: 'YYYY-MM-DD',
    zippedArchive: true,
    maxFiles: '90d',
    format: winston.format((info, opts) => {
        return info.level === 'error' ? false : info;
    })()
});
const logger = winston.createLogger({
    transports: [errorTransport, infoTransport],
});
if (process.env.NODE_ENV !== 'production') {
    logger.add(new winston.transports.Console({
        format: winston.format.simple(),
    }));
}
export { logger as Logger, };
