import { PaymentController } from '../controller/index.js';
import { Messages, Request } from '../helper/index.js';
import { ResponseError } from '../error/index.js';
import { Logger } from '../log/index.js';
class Payment {
    register(app) {
        app.post('/payment/:mode', async (req, res) => {
            try {
                if (!req.params || !req.params.mode) {
                    throw new Error('Payment mode not informed in endpoint url');
                }
                const response = await PaymentController.start(Request.getAllParams(req));
                const statusCode = Messages.isFailMessage(response.messageCode) ? 500 : 200;
                if (statusCode === 200) {
                    Logger.info(`[SUCCESS][${req.params.mode.toUpperCase()}] [NIT]: ${response.result.nit}`);
                }
                else {
                    Logger.error(`[${req.params.mode.toUpperCase()}] [NIT]: ${response.result.nit} | ${response.result.gatewayMessage}`);
                }
                res.status(statusCode).json(response);
            }
            catch (error) {
                Logger.error(`[${req.params.mode.toUpperCase()}] ${error.message}`);
                ResponseError.handle(res, error);
            }
        });
        app.post('/payment/confirm/:nit', async (req, res) => {
            try {
                if (!req.params || !req.params.nit) {
                    throw new Error('Payment nit not informed in endpoint url');
                }
                const response = await PaymentController.confirm(Request.getAllParams(req));
                const statusCode = Messages.isFailMessage(response.messageCode) ? 500 : 200;
                res.status(statusCode).json(response);
            }
            catch (error) {
                ResponseError.handle(res, error);
            }
        });
        app.post('/payment/cancel/:nit', async (req, res) => {
            try {
                if (!req.params || !req.params.nit) {
                    throw new Error('Payment nit not informed in endpoint url');
                }
                const response = await PaymentController.cancel(Request.getAllParams(req));
                const statusCode = Messages.isFailMessage(response.messageCode) ? 500 : 200;
                res.status(statusCode).json(response);
            }
            catch (error) {
                ResponseError.handle(res, error);
            }
        });
        app.post('/payment/consult/:nit', async (req, res) => {
            try {
                if (!req.params || !req.params.nit) {
                    throw new Error('Payment nit not informed in endpoint url');
                }
                const response = await PaymentController.consult(Request.getAllParams(req));
                const statusCode = Messages.isFailMessage(response.messageCode) ? 500 : 200;
                res.status(statusCode).json(response);
            }
            catch (error) {
                ResponseError.handle(res, error);
            }
        });
    }
}
const instance = new Payment();
export { instance as Payment };
